==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/USERKPIITEM_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour USERKPIITEM_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="USERKPIITEM_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMFUNCTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERFUNCTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EWSDATASPYID" minOccurs="0"/>
 *         &lt;element name="KPISCORE" type="{http://www.openapplications.org/oagis_segments}QUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMESEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORMFILTER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOWVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIGHVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KPICOLOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KPITYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DONUTRADIUSPERCENTAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROUPBYTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="hasChildren" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERKPIITEM_Type", propOrder = {
    "homeid",
    "icon",
    "uomcode",
    "systemfunction",
    "userfunction",
    "ewsdataspyid",
    "kpiscore",
    "homesequence",
    "formfilter",
    "lowvalue",
    "highvalue",
    "kpicolor",
    "kpitype",
    "donutradiuspercentage",
    "groupbytext"
})
public class USERKPIITEM_Type {

    @XmlElement(name = "HOMEID", required = true)
    protected HOMEID_Type homeid;
    @XmlElement(name = "ICON")
    protected String icon;
    @XmlElement(name = "UOMCODE")
    protected String uomcode;
    @XmlElement(name = "SYSTEMFUNCTION")
    protected String systemfunction;
    @XmlElement(name = "USERFUNCTION")
    protected String userfunction;
    @XmlElement(name = "EWSDATASPYID")
    protected Long ewsdataspyid;
    @XmlElement(name = "KPISCORE")
    protected QUANTITY kpiscore;
    @XmlElement(name = "HOMESEQUENCE")
    protected long homesequence;
    @XmlElement(name = "FORMFILTER")
    protected String formfilter;
    @XmlElement(name = "LOWVALUE")
    protected QUANTITY lowvalue;
    @XmlElement(name = "HIGHVALUE")
    protected QUANTITY highvalue;
    @XmlElement(name = "KPICOLOR")
    protected String kpicolor;
    @XmlElement(name = "KPITYPE")
    protected String kpitype;
    @XmlElement(name = "DONUTRADIUSPERCENTAGE")
    protected QUANTITY donutradiuspercentage;
    @XmlElement(name = "GROUPBYTEXT")
    protected String groupbytext;
    @XmlAttribute(name = "hasChildren")
    protected String hasChildren;

    /**
     * Obtient la valeur de la propriété homeid.
     * 
     * @return
     *     possible object is
     *     {@link HOMEID_Type }
     *     
     */
    public HOMEID_Type getHOMEID() {
        return homeid;
    }

    /**
     * Définit la valeur de la propriété homeid.
     * 
     * @param value
     *     allowed object is
     *     {@link HOMEID_Type }
     *     
     */
    public void setHOMEID(HOMEID_Type value) {
        this.homeid = value;
    }

    /**
     * Obtient la valeur de la propriété icon.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICON() {
        return icon;
    }

    /**
     * Définit la valeur de la propriété icon.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICON(String value) {
        this.icon = value;
    }

    /**
     * Obtient la valeur de la propriété uomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOMCODE() {
        return uomcode;
    }

    /**
     * Définit la valeur de la propriété uomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOMCODE(String value) {
        this.uomcode = value;
    }

    /**
     * Obtient la valeur de la propriété systemfunction.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSYSTEMFUNCTION() {
        return systemfunction;
    }

    /**
     * Définit la valeur de la propriété systemfunction.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSYSTEMFUNCTION(String value) {
        this.systemfunction = value;
    }

    /**
     * Obtient la valeur de la propriété userfunction.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERFUNCTION() {
        return userfunction;
    }

    /**
     * Définit la valeur de la propriété userfunction.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERFUNCTION(String value) {
        this.userfunction = value;
    }

    /**
     * Obtient la valeur de la propriété ewsdataspyid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getEWSDATASPYID() {
        return ewsdataspyid;
    }

    /**
     * Définit la valeur de la propriété ewsdataspyid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setEWSDATASPYID(Long value) {
        this.ewsdataspyid = value;
    }

    /**
     * Obtient la valeur de la propriété kpiscore.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getKPISCORE() {
        return kpiscore;
    }

    /**
     * Définit la valeur de la propriété kpiscore.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setKPISCORE(QUANTITY value) {
        this.kpiscore = value;
    }

    /**
     * Obtient la valeur de la propriété homesequence.
     * 
     */
    public long getHOMESEQUENCE() {
        return homesequence;
    }

    /**
     * Définit la valeur de la propriété homesequence.
     * 
     */
    public void setHOMESEQUENCE(long value) {
        this.homesequence = value;
    }

    /**
     * Obtient la valeur de la propriété formfilter.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFORMFILTER() {
        return formfilter;
    }

    /**
     * Définit la valeur de la propriété formfilter.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFORMFILTER(String value) {
        this.formfilter = value;
    }

    /**
     * Obtient la valeur de la propriété lowvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLOWVALUE() {
        return lowvalue;
    }

    /**
     * Définit la valeur de la propriété lowvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLOWVALUE(QUANTITY value) {
        this.lowvalue = value;
    }

    /**
     * Obtient la valeur de la propriété highvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHIGHVALUE() {
        return highvalue;
    }

    /**
     * Définit la valeur de la propriété highvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHIGHVALUE(QUANTITY value) {
        this.highvalue = value;
    }

    /**
     * Obtient la valeur de la propriété kpicolor.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKPICOLOR() {
        return kpicolor;
    }

    /**
     * Définit la valeur de la propriété kpicolor.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKPICOLOR(String value) {
        this.kpicolor = value;
    }

    /**
     * Obtient la valeur de la propriété kpitype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKPITYPE() {
        return kpitype;
    }

    /**
     * Définit la valeur de la propriété kpitype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKPITYPE(String value) {
        this.kpitype = value;
    }

    /**
     * Obtient la valeur de la propriété donutradiuspercentage.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDONUTRADIUSPERCENTAGE() {
        return donutradiuspercentage;
    }

    /**
     * Définit la valeur de la propriété donutradiuspercentage.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDONUTRADIUSPERCENTAGE(QUANTITY value) {
        this.donutradiuspercentage = value;
    }

    /**
     * Obtient la valeur de la propriété groupbytext.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGROUPBYTEXT() {
        return groupbytext;
    }

    /**
     * Définit la valeur de la propriété groupbytext.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGROUPBYTEXT(String value) {
        this.groupbytext = value;
    }

    /**
     * Obtient la valeur de la propriété hasChildren.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHasChildren() {
        if (hasChildren == null) {
            return "false";
        } else {
            return hasChildren;
        }
    }

    /**
     * Définit la valeur de la propriété hasChildren.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHasChildren(String value) {
        this.hasChildren = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/USERKPIITEM_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for USERKPIITEM_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="USERKPIITEM_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMFUNCTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERFUNCTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EWSDATASPYID" minOccurs="0"/>
 *         &lt;element name="KPISCORE" type="{http://www.openapplications.org/oagis_segments}QUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMESEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORMFILTER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOWVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIGHVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KPICOLOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KPITYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DONUTRADIUSPERCENTAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROUPBYTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="hasChildren" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERKPIITEM_Type", propOrder = {
    "homeid",
    "icon",
    "uomcode",
    "systemfunction",
    "userfunction",
    "ewsdataspyid",
    "kpiscore",
    "homesequence",
    "formfilter",
    "lowvalue",
    "highvalue",
    "kpicolor",
    "kpitype",
    "donutradiuspercentage",
    "groupbytext"
})
public class USERKPIITEM_Type {

    @XmlElement(name = "HOMEID", required = true)
    protected HOMEID_Type homeid;
    @XmlElement(name = "ICON")
    protected String icon;
    @XmlElement(name = "UOMCODE")
    protected String uomcode;
    @XmlElement(name = "SYSTEMFUNCTION")
    protected String systemfunction;
    @XmlElement(name = "USERFUNCTION")
    protected String userfunction;
    @XmlElement(name = "EWSDATASPYID")
    protected Long ewsdataspyid;
    @XmlElement(name = "KPISCORE")
    protected QUANTITY kpiscore;
    @XmlElement(name = "HOMESEQUENCE")
    protected long homesequence;
    @XmlElement(name = "FORMFILTER")
    protected String formfilter;
    @XmlElement(name = "LOWVALUE")
    protected QUANTITY lowvalue;
    @XmlElement(name = "HIGHVALUE")
    protected QUANTITY highvalue;
    @XmlElement(name = "KPICOLOR")
    protected String kpicolor;
    @XmlElement(name = "KPITYPE")
    protected String kpitype;
    @XmlElement(name = "DONUTRADIUSPERCENTAGE")
    protected QUANTITY donutradiuspercentage;
    @XmlElement(name = "GROUPBYTEXT")
    protected String groupbytext;
    @XmlAttribute(name = "hasChildren")
    protected String hasChildren;

    /**
     * Gets the value of the homeid property.
     * 
     * @return
     *     possible object is
     *     {@link HOMEID_Type }
     *     
     */
    public HOMEID_Type getHOMEID() {
        return homeid;
    }

    /**
     * Sets the value of the homeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link HOMEID_Type }
     *     
     */
    public void setHOMEID(HOMEID_Type value) {
        this.homeid = value;
    }

    /**
     * Gets the value of the icon property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICON() {
        return icon;
    }

    /**
     * Sets the value of the icon property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICON(String value) {
        this.icon = value;
    }

    /**
     * Gets the value of the uomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOMCODE() {
        return uomcode;
    }

    /**
     * Sets the value of the uomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOMCODE(String value) {
        this.uomcode = value;
    }

    /**
     * Gets the value of the systemfunction property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSYSTEMFUNCTION() {
        return systemfunction;
    }

    /**
     * Sets the value of the systemfunction property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSYSTEMFUNCTION(String value) {
        this.systemfunction = value;
    }

    /**
     * Gets the value of the userfunction property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERFUNCTION() {
        return userfunction;
    }

    /**
     * Sets the value of the userfunction property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERFUNCTION(String value) {
        this.userfunction = value;
    }

    /**
     * Gets the value of the ewsdataspyid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getEWSDATASPYID() {
        return ewsdataspyid;
    }

    /**
     * Sets the value of the ewsdataspyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setEWSDATASPYID(Long value) {
        this.ewsdataspyid = value;
    }

    /**
     * Gets the value of the kpiscore property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getKPISCORE() {
        return kpiscore;
    }

    /**
     * Sets the value of the kpiscore property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setKPISCORE(QUANTITY value) {
        this.kpiscore = value;
    }

    /**
     * Gets the value of the homesequence property.
     * 
     */
    public long getHOMESEQUENCE() {
        return homesequence;
    }

    /**
     * Sets the value of the homesequence property.
     * 
     */
    public void setHOMESEQUENCE(long value) {
        this.homesequence = value;
    }

    /**
     * Gets the value of the formfilter property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFORMFILTER() {
        return formfilter;
    }

    /**
     * Sets the value of the formfilter property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFORMFILTER(String value) {
        this.formfilter = value;
    }

    /**
     * Gets the value of the lowvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLOWVALUE() {
        return lowvalue;
    }

    /**
     * Sets the value of the lowvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLOWVALUE(QUANTITY value) {
        this.lowvalue = value;
    }

    /**
     * Gets the value of the highvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHIGHVALUE() {
        return highvalue;
    }

    /**
     * Sets the value of the highvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHIGHVALUE(QUANTITY value) {
        this.highvalue = value;
    }

    /**
     * Gets the value of the kpicolor property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKPICOLOR() {
        return kpicolor;
    }

    /**
     * Sets the value of the kpicolor property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKPICOLOR(String value) {
        this.kpicolor = value;
    }

    /**
     * Gets the value of the kpitype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKPITYPE() {
        return kpitype;
    }

    /**
     * Sets the value of the kpitype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKPITYPE(String value) {
        this.kpitype = value;
    }

    /**
     * Gets the value of the donutradiuspercentage property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDONUTRADIUSPERCENTAGE() {
        return donutradiuspercentage;
    }

    /**
     * Sets the value of the donutradiuspercentage property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDONUTRADIUSPERCENTAGE(QUANTITY value) {
        this.donutradiuspercentage = value;
    }

    /**
     * Gets the value of the groupbytext property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGROUPBYTEXT() {
        return groupbytext;
    }

    /**
     * Sets the value of the groupbytext property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGROUPBYTEXT(String value) {
        this.groupbytext = value;
    }

    /**
     * Gets the value of the hasChildren property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHasChildren() {
        if (hasChildren == null) {
            return "false";
        } else {
            return hasChildren;
        }
    }

    /**
     * Sets the value of the hasChildren property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHasChildren(String value) {
        this.hasChildren = value;
    }

}
